@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 from ...imports import *
-import os, logging, traceback, threading, io, sys, faulthandler, traceback, signal
+import clipboard,os, logging, traceback, threading, io, sys, faulthandler, traceback, signal
 from typing import *
 from dataclasses import dataclass
 from logging.handlers import RotatingFileHandler
